#!/usr/bin/env python
# -*- coding: ASCII -*-
'''TQFP44 footprint drawn from the Atmel ATmega162 Datasheet (2513K-AVR-07/09)
Copyright (c) 2011, Mel Wilson, mwilson@melwilsonsoftware.ca
Licence: Creative Commons Attribution 3.0 Unported License
<http://creativecommons.org/licenses/by-sa/3.0/>
'''
from footprinter import mm, Footprint, Pad, ElementArc, ElementLine
		
# Datasheet dimensions ..
ds_D = mm (12.25)		# datasheet dimension 'D' (max)
ds_D1 = mm (10)		# datasheet dimension 'D1' (nom)
ds_L = mm (0.75)		# datasheet dimension 'L' (max)
ds_e = mm (0.8)		# datasheet dimension 'e' (nom)
# Constants used to position a row of pads ..
PAD_PITCH = ds_e
PAD_CENTER = (ds_D - ds_L) / 2	# distance from the origin of the pad-centers in the row
ROW_ORIGIN = 5 * PAD_PITCH	# distance from the origin of one end of the row
PAD_HLENGTH = (ds_L) / 2	# half the length (long axis) of a pad
PAD_HWIDTH = PAD_PITCH / 4	# half the width (short axis) of a pad
OUTLINE_DIST = ds_D1 / 2	# half the edge of the chip outline rectangle
CENTER_WIDTH = ds_D1 * 3 / 5
CENTER_HWIDTH = CENTER_WIDTH / 2

TRACE_CLEARANCE = mm (0.035)
MASK_CLEARANCE = mm (0.025)
	
def pad_h (pin, center_x, center_y):
	'''Create a pad with the long edge horizontal.'''
	#~ return Pad (pin, padrect, trace_clearance, mask_clearance, name='', sflags=''):
	return Pad (pin
			, (center_x-PAD_HLENGTH,center_y-PAD_HWIDTH,  center_x+PAD_HLENGTH,center_y+PAD_HWIDTH)
			, TRACE_CLEARANCE, MASK_CLEARANCE, sflags='square')

def pad_v (pin, center_x, center_y):
	'''Create a pad with the long edge vertical.'''
	return Pad (pin
			, (center_x-PAD_HWIDTH,center_y-PAD_HLENGTH,  center_x+PAD_HWIDTH,center_y+PAD_HLENGTH)
			, TRACE_CLEARANCE, MASK_CLEARANCE, sflags='square')

fp = Footprint ([pad_h (p+1, -PAD_CENTER, p*PAD_PITCH-ROW_ORIGIN) for p in xrange (11)]	# pins 1..11
			+ [pad_v (p+12, p*PAD_PITCH-ROW_ORIGIN, PAD_CENTER) for p in xrange (11)]	# pins 12..22
			+ [pad_h (p+23, PAD_CENTER, -p*PAD_PITCH+ROW_ORIGIN) for p in xrange (11)]	# pins 23..33
			+ [pad_v (p+34, -p*PAD_PITCH+ROW_ORIGIN, -PAD_CENTER) for p in xrange (11)]	# pins 34..44
			# Central pad to solder the part down ..
			# BUG -- if the part is rotated 45 degrees, this central pad won't rotate with it ..
			+ [Pad (45, (-CENTER_HWIDTH-5,-CENTER_HWIDTH, CENTER_HWIDTH+5,CENTER_HWIDTH), TRACE_CLEARANCE, mm(0.05), sflags='square')]
	,
	[
		ElementArc (-mm(4), -mm(4), mm(0.25), mm(0.25), 0,360, mm(0.5)),	# dot to mark pin1
		# rectangle for chip outline ..
		ElementLine (-OUTLINE_DIST,-OUTLINE_DIST, -OUTLINE_DIST,OUTLINE_DIST, mm(0.1)),
		ElementLine (-OUTLINE_DIST,OUTLINE_DIST, OUTLINE_DIST,OUTLINE_DIST, mm(0.1)),
		ElementLine (OUTLINE_DIST,OUTLINE_DIST, OUTLINE_DIST,-OUTLINE_DIST, mm(0.1)),
		ElementLine (OUTLINE_DIST,-OUTLINE_DIST, -OUTLINE_DIST,-OUTLINE_DIST, mm(0.1)),
	]
	, description = "Atmel ATmega162 TQFP44"
	)
		
fp.file_element ('ATMEGA162_TQFP44.fp')
